@@ -1,3 +1,5 @@
+"""Autoblocks API Client."""
+
 import logging
 from dataclasses import asdict
 from datetime import timedelta
@@ -11,8 +13,8 @@ from typing import Union
 import httpx
 
 from autoblocks._impl.api.models import AbsoluteTimeFilter
-from autoblocks._impl.api.models import AutoblocksTestCaseResult
 from autoblocks._impl.api.models import AutoblocksTestCaseResultId
+from autoblocks._impl.api.models import AutoblocksTestCaseResultInPair
 from autoblocks._impl.api.models import AutoblocksTestCaseResultPair
 from autoblocks._impl.api.models import AutoblocksTestCaseResultPairId
 from autoblocks._impl.api.models import AutoblocksTestCaseResultWithEvaluations
@@ -236,7 +238,10 @@ class AutoblocksAPIClient:
             name=resp["name"],
             schema_version=f"{resp['schemaVersion']}",
             revision_id=resp["revisionId"],
-            items=[DatasetItem(id=item["id"], splits=item["splits"], data=item["data"]) for item in resp["items"]],
+            items=[
+                DatasetItem(id=item["id"], revision_id=resp["revisionId"], splits=item["splits"], data=item["data"])
+                for item in resp["items"]
+            ],
         )
 
     def get_local_test_runs(self, test_external_id: str) -> List[AutoblocksTestRun]:
@@ -379,32 +384,77 @@ class AutoblocksAPIClient:
         resp = req.json()
         pair = resp["pair"]
 
-        test_case_results = [
-            AutoblocksTestCaseResult(
-                id=result["id"],
-                run_id=result["runId"],
-                hash=result["hash"],
-                dataset_item_id=result.get("datasetItemId", None),
-                duration_ms=result.get("durationMs", None),
-                events=[
-                    Event(
-                        id=event["id"],
-                        trace_id=event["traceId"],
-                        message=event["message"],
-                        timestamp=event["timestamp"],
-                        properties=event.get("properties", None),
-                    )
-                    for event in result.get("events", [])
-                ],
-                body=result["body"],
-                output=result["output"],
-            )
-            for result in pair["testCaseResults"]
-        ]
-
         return AutoblocksTestCaseResultPair(
-            id=pair["id"],
-            hash=pair["hash"],
-            chosen_output_id=pair.get("chosenOutputId", None),
-            test_case_results=test_case_results,
+            pair_id=pair["pairId"],
+            chosen_id=pair.get("chosenId"),
+            test_cases=[
+                AutoblocksTestCaseResultInPair(
+                    id=tc["id"],
+                    input_fields=[
+                        HumanReviewField(id=f["id"], name=f["name"], value=f["value"], content_type=f["contentType"])
+                        for f in tc["inputFields"]
+                    ],
+                    output_fields=[
+                        HumanReviewField(id=f["id"], name=f["name"], value=f["value"], content_type=f["contentType"])
+                        for f in tc["outputFields"]
+                    ],
+                    field_comments=[
+                        HumanReviewFieldComment(
+                            field_id=c["fieldId"],
+                            start_idx=c.get("startIdx"),
+                            end_idx=c.get("endIdx"),
+                            value=c["value"],
+                            in_relation_to_grade_name=c.get("inRelationToGradeName"),
+                            in_relation_to_automated_evaluation_id=c.get("inRelationToAutomatedEvaluationId"),
+                        )
+                        for c in tc["fieldComments"]
+                    ],
+                    input_comments=[
+                        HumanReviewGeneralComment(
+                            value=c["value"],
+                            in_relation_to_grade_name=c.get("inRelationToGradeName"),
+                            in_relation_to_automated_evaluation_id=c.get("inRelationToAutomatedEvaluationId"),
+                        )
+                        for c in tc["inputComments"]
+                    ],
+                    output_comments=[
+                        HumanReviewGeneralComment(
+                            value=c["value"],
+                            in_relation_to_grade_name=c.get("inRelationToGradeName"),
+                            in_relation_to_automated_evaluation_id=c.get("inRelationToAutomatedEvaluationId"),
+                        )
+                        for c in tc["outputComments"]
+                    ],
+                )
+                for tc in pair["testCases"]
+            ],
         )
+
+    def add_dataset_item(
+        self, dataset_external_id: str, data: Dict[str, Any], splits: Optional[List[str]] = None
+    ) -> str:
+        split_names = splits or []
+        response = self._client.post(
+            f"/datasets/{encode_uri_component(dataset_external_id)}/items",
+            json={"data": data, "splitNames": split_names},
+        )
+        response.raise_for_status()
+        return str(response.json()["id"])
+
+    def delete_dataset_item(self, dataset_external_id: str, item_id: str) -> str:
+        response = self._client.delete(
+            f"/datasets/{encode_uri_component(dataset_external_id)}/items/{encode_uri_component(item_id)}"
+        )
+        response.raise_for_status()
+        return str(response.json()["id"])
+
+    def update_dataset_item(
+        self, dataset_external_id: str, item_id: str, data: Dict[str, Any], splits: Optional[List[str]] = None
+    ) -> str:
+        split_names = splits or []
+        response = self._client.put(
+            f"/datasets/{encode_uri_component(dataset_external_id)}/items/{encode_uri_component(item_id)}",
+            json={"data": data, "splitNames": split_names},
+        )
+        response.raise_for_status()
+        return str(response.json()["id"])
