@@ -191,6 +191,7 @@ class HumanReviewJobTestCaseResult:
 @dataclass
 class DatasetItem:
     id: str
+    revision_id: str
     splits: List[str]
     data: Dict[str, Any]
 
@@ -254,8 +255,17 @@ class AutoblocksTestCaseResultPairId:
 
 
 @dataclass
-class AutoblocksTestCaseResultPair:
+class AutoblocksTestCaseResultInPair:
     id: str
-    hash: str
-    chosen_output_id: Optional[str]
-    test_case_results: List[AutoblocksTestCaseResult]
+    input_fields: List[HumanReviewField]
+    output_fields: List[HumanReviewField]
+    field_comments: List[HumanReviewFieldComment]
+    input_comments: List[HumanReviewGeneralComment]
+    output_comments: List[HumanReviewGeneralComment]
+
+
+@dataclass
+class AutoblocksTestCaseResultPair:
+    pair_id: str
+    chosen_id: Optional[str]
+    test_cases: List[AutoblocksTestCaseResultInPair]
