@@ -14,12 +14,19 @@ from typing import Tuple
 from typing import Union
 from typing import overload
 
+import httpx
+from tenacity import retry
+from tenacity import retry_if_exception_type
+from tenacity import stop_after_attempt
+from tenacity import wait_random_exponential
+
 from autoblocks._impl import global_state
 from autoblocks._impl.context_vars import EvaluatorRunContext
 from autoblocks._impl.context_vars import TestCaseRunContext
 from autoblocks._impl.context_vars import evaluator_run_context_var
 from autoblocks._impl.context_vars import grid_search_context_var
 from autoblocks._impl.context_vars import test_case_run_context_var
+from autoblocks._impl.testing.api import send_create_human_review_job
 from autoblocks._impl.testing.api import send_end_test_run
 from autoblocks._impl.testing.api import send_error
 from autoblocks._impl.testing.api import send_eval
@@ -31,6 +38,7 @@ from autoblocks._impl.testing.api import send_start_test_run
 from autoblocks._impl.testing.api import send_test_case_result
 from autoblocks._impl.testing.models import BaseTestCase
 from autoblocks._impl.testing.models import BaseTestEvaluator
+from autoblocks._impl.testing.models import CreateHumanReviewJob
 from autoblocks._impl.testing.models import TestCaseContext
 from autoblocks._impl.testing.models import TestCaseType
 from autoblocks._impl.testing.util import GridSearchParams
@@ -40,6 +48,7 @@ from autoblocks._impl.testing.util import yield_test_case_contexts_from_test_cas
 from autoblocks._impl.util import AutoblocksEnvVar
 from autoblocks._impl.util import all_settled
 from autoblocks._impl.util import is_cli_running
+from autoblocks._impl.util import parse_autoblocks_overrides
 
 log = logging.getLogger(__name__)
 
@@ -49,6 +58,32 @@ evaluator_semaphore_registry: dict[str, dict[str, asyncio.Semaphore]] = {}  # te
 DEFAULT_MAX_TEST_CASE_CONCURRENCY = 10
 
 
+def create_retry_decorator(retry_count: int) -> Callable[[Callable[..., Any]], Callable[..., Any]]:
+    """Create retry decorator following existing tenacity pattern."""
+    if retry_count <= 0:
+        # No retry - return identity decorator
+        def no_retry_decorator(func: Callable[..., Any]) -> Callable[..., Any]:
+            return func
+
+        return no_retry_decorator
+
+    # Use same pattern as existing code in api.py
+    return retry(
+        stop=stop_after_attempt(retry_count + 1),  # +1 because first attempt isn't a retry
+        wait=wait_random_exponential(multiplier=1, max=30),
+        retry=retry_if_exception_type(
+            (
+                httpx.TimeoutException,
+                httpx.ConnectError,
+                httpx.ReadTimeout,
+                httpx.WriteTimeout,
+                httpx.PoolTimeout,
+            )
+        ),
+        reraise=True,
+    )
+
+
 def tests_and_hashes_overrides_map() -> Optional[dict[str, list[str]]]:
     """
     AUTOBLOCKS_OVERRIDES_TESTS_AND_HASHES is a JSON string that maps test suite IDs to a list of test case hashes.
@@ -222,6 +257,7 @@ async def run_test_case(
     evaluators: Sequence[BaseTestEvaluator],
     fn: Union[Callable[[TestCaseType], Any], Callable[[TestCaseType], Awaitable[Any]]],
     before_evaluators_hook: Optional[Callable[[TestCaseType, Any], Any]],
+    retry_count: int = 0,
 ) -> None:
     reset_token = test_case_run_context_var.set(
         TestCaseRunContext(
@@ -230,14 +266,23 @@ async def run_test_case(
             test_case_hash=test_case_ctx.hash(),
         ),
     )
-    try:
-        output, hook_results, test_case_result_id = await run_test_case_unsafe(
+
+    # Create retry decorator
+    retry_decorator = create_retry_decorator(retry_count)
+
+    # Wrap the unsafe function with retry logic
+    @retry_decorator
+    async def _retry_wrapper() -> Tuple[Any, Any, str]:
+        return await run_test_case_unsafe(
             test_id=test_id,
             run_id=run_id,
             test_case_ctx=test_case_ctx,
             fn=fn,
             before_evaluators_hook=before_evaluators_hook,
         )
+
+    try:
+        output, hook_results, test_case_result_id = await _retry_wrapper()
     except Exception as err:
         await send_error(
             test_id=test_id,
@@ -359,11 +404,17 @@ async def run_test_suite_for_grid_combo(
     before_evaluators_hook: Optional[Callable[[TestCaseType, Any], Any]],
     grid_search_run_group_id: Optional[str],
     grid_search_params_combo: Optional[GridSearchParamsCombo],
+    human_review_job: Optional[CreateHumanReviewJob],
+    retry_count: int = 0,
 ) -> None:
     try:
+        # Determine message with priority: unified overrides > legacy env var
+        overrides = parse_autoblocks_overrides()
+        message = overrides.test_run_message or AutoblocksEnvVar.TEST_RUN_MESSAGE.get()
+
         run_id = await send_start_test_run(
             test_external_id=test_id,
-            message=AutoblocksEnvVar.TEST_RUN_MESSAGE.get(),
+            message=message,
             grid_search_run_group_id=grid_search_run_group_id,
             grid_search_params_combo=grid_search_params_combo,
         )
@@ -394,6 +445,7 @@ async def run_test_suite_for_grid_combo(
                     evaluators=evaluators,
                     fn=fn,
                     before_evaluators_hook=before_evaluators_hook,
+                    retry_count=retry_count,
                 )
                 for test_case_ctx in yield_test_case_contexts_from_test_cases(test_cases)
             ],
@@ -414,6 +466,23 @@ async def run_test_suite_for_grid_combo(
         test_external_id=test_id,
         run_id=run_id,
     )
+
+    if human_review_job is not None:
+        try:
+            assignee_email_addresses = human_review_job.get_assignee_email_addresses()
+            await all_settled(
+                [
+                    send_create_human_review_job(
+                        run_id=run_id,
+                        assignee_email_address=assignee_email_address,
+                        name=human_review_job.name,
+                    )
+                    for assignee_email_address in assignee_email_addresses
+                ]
+            )
+        except Exception as err:
+            log.warning(f"Failed to create human review job for test run '{run_id}'", exc_info=err)
+
     await all_settled(
         [
             send_slack_notification(run_id=run_id),
@@ -431,6 +500,8 @@ async def async_run_test_suite(
     max_test_case_concurrency: int,
     caller_filepath: Optional[str],
     grid_search_params: Optional[GridSearchParams],
+    human_review_job: Optional[CreateHumanReviewJob],
+    retry_count: int = 0,
 ) -> None:
     # Handle alignment mode
     align_test_id = AutoblocksEnvVar.ALIGN_TEST_EXTERNAL_ID.get()
@@ -505,6 +576,8 @@ async def async_run_test_suite(
                 before_evaluators_hook=before_evaluators_hook,
                 grid_search_run_group_id=None,
                 grid_search_params_combo=None,
+                human_review_job=human_review_job,
+                retry_count=retry_count,
             )
         except Exception as err:
             await send_error(
@@ -547,6 +620,8 @@ async def async_run_test_suite(
                     before_evaluators_hook=before_evaluators_hook,
                     grid_search_run_group_id=grid_search_run_group_id,
                     grid_search_params_combo=grid_params_combo,
+                    human_review_job=human_review_job,
+                    retry_count=retry_count,
                 )
                 for grid_params_combo in yield_grid_search_param_combos(grid_search_params)
             ],
@@ -571,6 +646,8 @@ def run_test_suite(
     max_test_case_concurrency: int = DEFAULT_MAX_TEST_CASE_CONCURRENCY,
     before_evaluators_hook: Optional[Callable[[TestCaseType, Any], Any]] = None,
     grid_search_params: Optional[GridSearchParams] = None,
+    human_review_job: Optional[CreateHumanReviewJob] = None,
+    retry_count: int = 0,
 ) -> None: ...
 
 
@@ -584,6 +661,8 @@ def run_test_suite(
     max_test_case_concurrency: int = DEFAULT_MAX_TEST_CASE_CONCURRENCY,
     before_evaluators_hook: Optional[Callable[[TestCaseType, Any], Any]] = None,
     grid_search_params: Optional[GridSearchParams] = None,
+    human_review_job: Optional[CreateHumanReviewJob] = None,
+    retry_count: int = 0,
 ) -> None: ...
 
 
@@ -596,6 +675,8 @@ def run_test_suite(
     max_test_case_concurrency: int = DEFAULT_MAX_TEST_CASE_CONCURRENCY,
     before_evaluators_hook: Optional[Callable[[TestCaseType, Any], Any]] = None,
     grid_search_params: Optional[GridSearchParams] = None,
+    human_review_job: Optional[CreateHumanReviewJob] = None,
+    retry_count: int = 0,
 ) -> None:
     if not is_cli_running():
         log.info(f"Running test suite '{id}'")
@@ -617,6 +698,8 @@ def run_test_suite(
             max_test_case_concurrency=max_test_case_concurrency,
             caller_filepath=caller_filepath,
             grid_search_params=grid_search_params,
+            human_review_job=human_review_job,
+            retry_count=retry_count,
         ),
         global_state.event_loop(),
     ).result()
