@@ -2,8 +2,4 @@ from autoblocks._impl.context_vars import grid_search_ctx
 from autoblocks._impl.testing.run import run_test_suite
 from autoblocks._impl.testing.run_manager import RunManager
 
-__all__ = [
-    "run_test_suite",
-    "grid_search_ctx",
-    "RunManager",
-]
+__all__ = ["run_test_suite", "grid_search_ctx", "RunManager"]
